@@ -14,11 +14,8 @@
 #include <QObject>
 #include <QString>
 
-#include "libbugzilla/clients/attachmentclient.h"
-#include "libbugzilla/clients/bugclient.h"
-#include "libbugzilla/clients/productclient.h"
-
-#include "../drkonqi_globals.h"
+#include "libbugzilla/clients/commands/newbug.h"
+#include "libbugzilla/models/product.h"
 
 namespace KIO
 {
@@ -42,41 +39,28 @@ public:
     QString getUsername() const;
 
     /* Bugzilla Action methods */
-    void fetchBugReport(int, QObject *jobOwner = nullptr);
-    Q_INVOKABLE void searchBugs(const QStringList &products, const QString &severity, const QString &comment, int offset);
     void sendReport(const Bugzilla::NewBug &bug);
     void attachTextToReport(const QString &text, const QString &filename, const QString &description, int bugId, const QString &comment);
-    void addMeToCC(int bugId);
     void fetchProductInfo(const QString &);
 
     /* Misc methods */
     QString urlForBug(int bug_number) const;
-    void stopCurrentSearch();
-
-    void fetchComments(const Bugzilla::Bug::Ptr &bug, QObject *jobOwner);
     Q_SCRIPTABLE void lookupVersion();
 
 Q_SIGNALS:
     /* Bugzilla actions finished successfully */
     void loginFinished(bool logged);
-    void bugReportFetched(Bugzilla::Bug::Ptr bug, QObject *jobOwner);
-    void commentsFetched(QList<Bugzilla::Comment::Ptr> comments, QObject *jobOwner);
-    void searchFinished(const QList<Bugzilla::Bug::Ptr> &bug);
     void reportSent(int bugId);
     void attachToReportSent(int bugId);
-    void addMeToCCFinished(int bugId);
     void productInfoFetched(const Bugzilla::Product::Ptr &product);
     void bugzillaVersionFound();
 
     /* Bugzilla actions had errors */
     void loginError(const QString &errorMsg);
     void bugReportError(const QString &errorMsg, QObject *jobOwner);
-    void commentsError(const QString &errorMsg, QObject *jobOwner);
-    void searchError(const QString &errorMsg);
     void sendReportError(const QString &errorMsg);
     void sendReportErrorInvalidValues(); // To use default values
     void attachToReportError(const QString &errorMsg);
-    void addMeToCCError(const QString &errorMsg);
     void productInfoError();
     void bugzillaVersionError(const QString &errorMsg);
 
@@ -87,8 +71,6 @@ private:
     QString m_password;
     bool m_logged = false;
 
-    KJob *m_searchJob = nullptr;
-
     void setFeaturesForVersion(const QString &version);
 };
 
