@@ -5,6 +5,7 @@
 
 #include <QClipboard>
 #include <QGuiApplication>
+#include <QUrl>
 
 #include "crashedapplication.h"
 #include "drkonqi.h"
@@ -29,6 +30,12 @@ QString Doctore::kdeBugzillaURL()
     return DrKonqi::kdeBugzillaURL();
 }
 
+QString Doctore::kdeBugzillaDomain()
+{
+    QUrl bugzillaUrl(DrKonqi::kdeBugzillaURL());
+    return bugzillaUrl.host();
+}
+
 bool Doctore::isSafer()
 {
     return DrKonqi::isSafer();
@@ -43,3 +50,5 @@ Q_INVOKABLE bool Doctore::ignoreQuality()
 {
     return DrKonqi::ignoreQuality();
 }
+
+#include "moc_doctore.cpp"
